//
//  LJSegmentSliderView.swift
//  XZClassPlatform
//
//  Created by liujun on 16/4/15.
//  Copyright © 2016年 Rock. All rights reserved.
//

import UIKit

protocol LJSegmentSliderViewDelegate : NSObjectProtocol {
    
    func segmentSliderView(segmentSliderView: LJSegmentSliderView, clickBtn: UIButton, clickIndex: Int)
}

class LJSegmentSliderView: UIView {

    weak var delegate: LJSegmentSliderViewDelegate?
    private var scrollView: UIScrollView?
    private var titles: [String]?
    private var titleSpace: CGFloat?
    private var sliderLine: UIView?
    var titleBtns: [UIButton] = []
    private var titleBtn: UIButton?
    private var btnIndex = 0
    
    private override init(frame: CGRect) {
        super.init(frame: frame)
    }

    convenience init(frame: CGRect, scrollView: UIScrollView, titles: [String], titleSpace: CGFloat = 40) {
        self.init(frame: frame)
        
        self.titles = titles
        self.titleSpace = titleSpace
        self.scrollView = scrollView
        self.scrollView?.addObserver(self, forKeyPath: "contentOffset", options: .New, context: nil)
        self.layoutUI()
    }
    
    func layoutUI() {
        let totalSpace = CGFloat(((self.titles?.count)! - 1))*self.titleSpace!
        let titleBtnWidth = (self.frame.size.width - CGFloat(totalSpace)) / CGFloat(self.titles!.count)
        
        if titles != nil {
            for i in 0..<self.titles!.count {
                
                let titleBtn = UIButton(frame: CGRectMake((titleBtnWidth + self.titleSpace!)*CGFloat(i), 0, titleBtnWidth, self.frame.size.height))
                titleBtn.setTitle(self.titles![i], forState: .Normal)
                titleBtn.setTitleColor(UIColor.blackColor(), forState: .Normal)
                titleBtn.titleLabel?.font = UIFont.systemFontOfSize(20)
                titleBtn.addTarget(self, action: #selector(LJSegmentSliderView.titleBtnClick(_:)), forControlEvents: .TouchUpInside)
                self.addSubview(titleBtn)
                self.titleBtns.append(titleBtn)
                
                if i == 0 {
                    let sliderLine = UIView(frame: CGRectMake((titleBtnWidth + self.titleSpace!)*CGFloat(i), titleBtn.frame.size.height - 2, titleBtnWidth, 2))
                    sliderLine.backgroundColor = HEX(0x3ac671)
                    self.sliderLine = sliderLine
                    self.sliderLine?.hidden = true // 将true改为false则sliderLine显示
                    self.addSubview(sliderLine)
                    titleBtn.setTitleColor(HEX(0x3ac671), forState: .Normal)
                    self.titleBtnClick(titleBtn)
                }
            }
        }
    }

    required init?(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
    }
    
    func titleBtnClick(titleBtn: UIButton) {
        
        for (index, btn)in self.titleBtns.enumerate() {
            if btn.titleLabel?.text == titleBtn.titleLabel?.text {
                self.btnIndex = index
            }
        }
        
        self.titleBtn?.setTitleColor(HEX(0x1d2d24), forState: .Normal)
        UIView.animateWithDuration(0.2) { () -> Void in
            
            let frame = CGRectMake(titleBtn.frame.origin.x, titleBtn.frame.size.height - 2, titleBtn.frame.size.width, 2)
            self.sliderLine?.frame = frame
        }
        titleBtn.setTitleColor(HEX(0x3ac671), forState: .Normal)
        self.titleBtn = titleBtn
        if self.scrollView != nil {
            
            self.scrollView!.scrollRectToVisible(CGRectMake(self.scrollView!.width*CGFloat(self.btnIndex), 0, self.scrollView!.width, self.scrollView!.height), animated: false)
        }
        
        if self.delegate?.respondsToSelector(Selector("segmentSliderView:tapBtn:")) == true {
            
            self.delegate?.segmentSliderView(self, clickBtn: titleBtn, clickIndex: self.btnIndex)
        }

    }
    
    override func observeValueForKeyPath(keyPath: String?, ofObject object: AnyObject?, change: [String : AnyObject]?, context: UnsafeMutablePointer<Void>) {

        if self.scrollView!.dragging || self.scrollView!.decelerating {
            
            let ratio = Float(self.scrollView!.contentOffset.x / self.scrollView!.width)
            self.sliderLine!.left = CGFloat(ratio) * (self.sliderLine!.width + self.titleSpace!)
            
            if ratio < ceilf(ratio) && self.titleBtns.count != 1 {
                
                self.titleBtns[Int(ratio)].titleLabel?.textColor = UIColor.colorWithInterpolationFromValue(HEX(0x3ac671), toValue: HEX(0x1d2d24), ratio: CGFloat(ratio) - CGFloat(Int(ratio)))
                
                self.titleBtns[Int(ceilf(ratio))].titleLabel?.textColor = UIColor.colorWithInterpolationFromValue(HEX(0x1d2d24), toValue: HEX(0x3ac671), ratio: CGFloat(ratio) - CGFloat(Int(ratio)))
            }
        }
    }
}
